
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include <ModemManager.h>
#ifndef __MM_ENUMS_TYPES_H__
#define __MM_ENUMS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "ModemManager-enums.h" */
GType mm_modem_lock_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_LOCK (mm_modem_lock_get_type ())

/**
 * mm_modem_lock_get_string:
 * @val: a MMModemLock.
 *
 * Gets the nickname string for the #MMModemLock specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_lock_get_string (MMModemLock val);
GType mm_modem_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_STATE (mm_modem_state_get_type ())

/**
 * mm_modem_state_get_string:
 * @val: a MMModemState.
 *
 * Gets the nickname string for the #MMModemState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_state_get_string (MMModemState val);
GType mm_modem_state_failed_reason_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_STATE_FAILED_REASON (mm_modem_state_failed_reason_get_type ())

/**
 * mm_modem_state_failed_reason_get_string:
 * @val: a MMModemStateFailedReason.
 *
 * Gets the nickname string for the #MMModemStateFailedReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_state_failed_reason_get_string (MMModemStateFailedReason val);
GType mm_modem_power_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_POWER_STATE (mm_modem_power_state_get_type ())

/**
 * mm_modem_power_state_get_string:
 * @val: a MMModemPowerState.
 *
 * Gets the nickname string for the #MMModemPowerState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_power_state_get_string (MMModemPowerState val);
GType mm_modem_state_change_reason_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_STATE_CHANGE_REASON (mm_modem_state_change_reason_get_type ())

/**
 * mm_modem_state_change_reason_get_string:
 * @val: a MMModemStateChangeReason.
 *
 * Gets the nickname string for the #MMModemStateChangeReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_state_change_reason_get_string (MMModemStateChangeReason val);
GType mm_modem_band_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_BAND (mm_modem_band_get_type ())

/**
 * mm_modem_band_get_string:
 * @val: a MMModemBand.
 *
 * Gets the nickname string for the #MMModemBand specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_band_get_string (MMModemBand val);
GType mm_modem_port_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_PORT_TYPE (mm_modem_port_type_get_type ())

/**
 * mm_modem_port_type_get_string:
 * @val: a MMModemPortType.
 *
 * Gets the nickname string for the #MMModemPortType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_port_type_get_string (MMModemPortType val);
GType mm_cell_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_CELL_TYPE (mm_cell_type_get_type ())

/**
 * mm_cell_type_get_string:
 * @val: a MMCellType.
 *
 * Gets the nickname string for the #MMCellType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_cell_type_get_string (MMCellType val);
GType mm_sms_pdu_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_PDU_TYPE (mm_sms_pdu_type_get_type ())

/**
 * mm_sms_pdu_type_get_string:
 * @val: a MMSmsPduType.
 *
 * Gets the nickname string for the #MMSmsPduType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_pdu_type_get_string (MMSmsPduType val);
GType mm_sms_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_STATE (mm_sms_state_get_type ())

/**
 * mm_sms_state_get_string:
 * @val: a MMSmsState.
 *
 * Gets the nickname string for the #MMSmsState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_state_get_string (MMSmsState val);
GType mm_sms_delivery_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_DELIVERY_STATE (mm_sms_delivery_state_get_type ())

/**
 * mm_sms_delivery_state_get_string:
 * @val: a MMSmsDeliveryState.
 *
 * Gets the nickname string for the #MMSmsDeliveryState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_delivery_state_get_string (MMSmsDeliveryState val);
GType mm_sms_storage_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_STORAGE (mm_sms_storage_get_type ())

/**
 * mm_sms_storage_get_string:
 * @val: a MMSmsStorage.
 *
 * Gets the nickname string for the #MMSmsStorage specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_storage_get_string (MMSmsStorage val);
GType mm_sms_validity_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_VALIDITY_TYPE (mm_sms_validity_type_get_type ())

/**
 * mm_sms_validity_type_get_string:
 * @val: a MMSmsValidityType.
 *
 * Gets the nickname string for the #MMSmsValidityType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_validity_type_get_string (MMSmsValidityType val);
GType mm_sms_cdma_teleservice_id_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_CDMA_TELESERVICE_ID (mm_sms_cdma_teleservice_id_get_type ())

/**
 * mm_sms_cdma_teleservice_id_get_string:
 * @val: a MMSmsCdmaTeleserviceId.
 *
 * Gets the nickname string for the #MMSmsCdmaTeleserviceId specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_cdma_teleservice_id_get_string (MMSmsCdmaTeleserviceId val);
GType mm_sms_cdma_service_category_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SMS_CDMA_SERVICE_CATEGORY (mm_sms_cdma_service_category_get_type ())

/**
 * mm_sms_cdma_service_category_get_string:
 * @val: a MMSmsCdmaServiceCategory.
 *
 * Gets the nickname string for the #MMSmsCdmaServiceCategory specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sms_cdma_service_category_get_string (MMSmsCdmaServiceCategory val);
GType mm_cbm_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_CBM_STATE (mm_cbm_state_get_type ())

/**
 * mm_cbm_state_get_string:
 * @val: a MMCbmState.
 *
 * Gets the nickname string for the #MMCbmState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_cbm_state_get_string (MMCbmState val);
GType mm_modem_contacts_storage_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_CONTACTS_STORAGE (mm_modem_contacts_storage_get_type ())

/**
 * mm_modem_contacts_storage_get_string:
 * @val: a MMModemContactsStorage.
 *
 * Gets the nickname string for the #MMModemContactsStorage specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_contacts_storage_get_string (MMModemContactsStorage val);
GType mm_bearer_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_TYPE (mm_bearer_type_get_type ())

/**
 * mm_bearer_type_get_string:
 * @val: a MMBearerType.
 *
 * Gets the nickname string for the #MMBearerType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_bearer_type_get_string (MMBearerType val);
GType mm_bearer_ip_method_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_IP_METHOD (mm_bearer_ip_method_get_type ())

/**
 * mm_bearer_ip_method_get_string:
 * @val: a MMBearerIpMethod.
 *
 * Gets the nickname string for the #MMBearerIpMethod specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_bearer_ip_method_get_string (MMBearerIpMethod val);
GType mm_modem_cdma_registration_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_CDMA_REGISTRATION_STATE (mm_modem_cdma_registration_state_get_type ())

/**
 * mm_modem_cdma_registration_state_get_string:
 * @val: a MMModemCdmaRegistrationState.
 *
 * Gets the nickname string for the #MMModemCdmaRegistrationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_cdma_registration_state_get_string (MMModemCdmaRegistrationState val);
GType mm_modem_cdma_activation_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_CDMA_ACTIVATION_STATE (mm_modem_cdma_activation_state_get_type ())

/**
 * mm_modem_cdma_activation_state_get_string:
 * @val: a MMModemCdmaActivationState.
 *
 * Gets the nickname string for the #MMModemCdmaActivationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_cdma_activation_state_get_string (MMModemCdmaActivationState val);
GType mm_modem_cdma_rm_protocol_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_CDMA_RM_PROTOCOL (mm_modem_cdma_rm_protocol_get_type ())

/**
 * mm_modem_cdma_rm_protocol_get_string:
 * @val: a MMModemCdmaRmProtocol.
 *
 * Gets the nickname string for the #MMModemCdmaRmProtocol specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_cdma_rm_protocol_get_string (MMModemCdmaRmProtocol val);
GType mm_modem_3gpp_registration_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_REGISTRATION_STATE (mm_modem_3gpp_registration_state_get_type ())

/**
 * mm_modem_3gpp_registration_state_get_string:
 * @val: a MMModem3gppRegistrationState.
 *
 * Gets the nickname string for the #MMModem3gppRegistrationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_registration_state_get_string (MMModem3gppRegistrationState val);
GType mm_modem_3gpp_network_availability_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_NETWORK_AVAILABILITY (mm_modem_3gpp_network_availability_get_type ())

/**
 * mm_modem_3gpp_network_availability_get_string:
 * @val: a MMModem3gppNetworkAvailability.
 *
 * Gets the nickname string for the #MMModem3gppNetworkAvailability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_network_availability_get_string (MMModem3gppNetworkAvailability val);
GType mm_modem_3gpp_subscription_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_SUBSCRIPTION_STATE (mm_modem_3gpp_subscription_state_get_type ())

/**
 * mm_modem_3gpp_subscription_state_get_string:
 * @val: a MMModem3gppSubscriptionState.
 *
 * Gets the nickname string for the #MMModem3gppSubscriptionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_subscription_state_get_string (MMModem3gppSubscriptionState val);
GType mm_modem_3gpp_ussd_session_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_USSD_SESSION_STATE (mm_modem_3gpp_ussd_session_state_get_type ())

/**
 * mm_modem_3gpp_ussd_session_state_get_string:
 * @val: a MMModem3gppUssdSessionState.
 *
 * Gets the nickname string for the #MMModem3gppUssdSessionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_ussd_session_state_get_string (MMModem3gppUssdSessionState val);
GType mm_modem_3gpp_eps_ue_mode_operation_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_EPS_UE_MODE_OPERATION (mm_modem_3gpp_eps_ue_mode_operation_get_type ())

/**
 * mm_modem_3gpp_eps_ue_mode_operation_get_string:
 * @val: a MMModem3gppEpsUeModeOperation.
 *
 * Gets the nickname string for the #MMModem3gppEpsUeModeOperation specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_eps_ue_mode_operation_get_string (MMModem3gppEpsUeModeOperation val);
GType mm_firmware_image_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_FIRMWARE_IMAGE_TYPE (mm_firmware_image_type_get_type ())

/**
 * mm_firmware_image_type_get_string:
 * @val: a MMFirmwareImageType.
 *
 * Gets the nickname string for the #MMFirmwareImageType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_firmware_image_type_get_string (MMFirmwareImageType val);
GType mm_oma_session_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_OMA_SESSION_TYPE (mm_oma_session_type_get_type ())

/**
 * mm_oma_session_type_get_string:
 * @val: a MMOmaSessionType.
 *
 * Gets the nickname string for the #MMOmaSessionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_oma_session_type_get_string (MMOmaSessionType val);
GType mm_oma_session_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_OMA_SESSION_STATE (mm_oma_session_state_get_type ())

/**
 * mm_oma_session_state_get_string:
 * @val: a MMOmaSessionState.
 *
 * Gets the nickname string for the #MMOmaSessionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_oma_session_state_get_string (MMOmaSessionState val);
GType mm_oma_session_state_failed_reason_get_type (void) G_GNUC_CONST;
#define MM_TYPE_OMA_SESSION_STATE_FAILED_REASON (mm_oma_session_state_failed_reason_get_type ())

/**
 * mm_oma_session_state_failed_reason_get_string:
 * @val: a MMOmaSessionStateFailedReason.
 *
 * Gets the nickname string for the #MMOmaSessionStateFailedReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_oma_session_state_failed_reason_get_string (MMOmaSessionStateFailedReason val);
GType mm_call_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_CALL_STATE (mm_call_state_get_type ())

/**
 * mm_call_state_get_string:
 * @val: a MMCallState.
 *
 * Gets the nickname string for the #MMCallState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_call_state_get_string (MMCallState val);
GType mm_call_state_reason_get_type (void) G_GNUC_CONST;
#define MM_TYPE_CALL_STATE_REASON (mm_call_state_reason_get_type ())

/**
 * mm_call_state_reason_get_string:
 * @val: a MMCallStateReason.
 *
 * Gets the nickname string for the #MMCallStateReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_call_state_reason_get_string (MMCallStateReason val);
GType mm_call_direction_get_type (void) G_GNUC_CONST;
#define MM_TYPE_CALL_DIRECTION (mm_call_direction_get_type ())

/**
 * mm_call_direction_get_string:
 * @val: a MMCallDirection.
 *
 * Gets the nickname string for the #MMCallDirection specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_call_direction_get_string (MMCallDirection val);
GType mm_bearer_multiplex_support_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_MULTIPLEX_SUPPORT (mm_bearer_multiplex_support_get_type ())

/**
 * mm_bearer_multiplex_support_get_string:
 * @val: a MMBearerMultiplexSupport.
 *
 * Gets the nickname string for the #MMBearerMultiplexSupport specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_bearer_multiplex_support_get_string (MMBearerMultiplexSupport val);
GType mm_modem_3gpp_packet_service_state_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_PACKET_SERVICE_STATE (mm_modem_3gpp_packet_service_state_get_type ())

/**
 * mm_modem_3gpp_packet_service_state_get_string:
 * @val: a MMModem3gppPacketServiceState.
 *
 * Gets the nickname string for the #MMModem3gppPacketServiceState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_packet_service_state_get_string (MMModem3gppPacketServiceState val);
GType mm_sim_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SIM_TYPE (mm_sim_type_get_type ())

/**
 * mm_sim_type_get_string:
 * @val: a MMSimType.
 *
 * Gets the nickname string for the #MMSimType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sim_type_get_string (MMSimType val);
GType mm_sim_esim_status_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SIM_ESIM_STATUS (mm_sim_esim_status_get_type ())

/**
 * mm_sim_esim_status_get_string:
 * @val: a MMSimEsimStatus.
 *
 * Gets the nickname string for the #MMSimEsimStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sim_esim_status_get_string (MMSimEsimStatus val);
GType mm_sim_removability_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SIM_REMOVABILITY (mm_sim_removability_get_type ())

/**
 * mm_sim_removability_get_string:
 * @val: a MMSimRemovability.
 *
 * Gets the nickname string for the #MMSimRemovability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_sim_removability_get_string (MMSimRemovability val);
GType mm_modem_3gpp_mico_mode_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_MICO_MODE (mm_modem_3gpp_mico_mode_get_type ())

/**
 * mm_modem_3gpp_mico_mode_get_string:
 * @val: a MMModem3gppMicoMode.
 *
 * Gets the nickname string for the #MMModem3gppMicoMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_mico_mode_get_string (MMModem3gppMicoMode val);
GType mm_modem_3gpp_drx_cycle_get_type (void) G_GNUC_CONST;
#define MM_TYPE_MODEM_3GPP_DRX_CYCLE (mm_modem_3gpp_drx_cycle_get_type ())

/**
 * mm_modem_3gpp_drx_cycle_get_string:
 * @val: a MMModem3gppDrxCycle.
 *
 * Gets the nickname string for the #MMModem3gppDrxCycle specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_modem_3gpp_drx_cycle_get_string (MMModem3gppDrxCycle val);
GType mm_bearer_access_type_preference_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_ACCESS_TYPE_PREFERENCE (mm_bearer_access_type_preference_get_type ())

/**
 * mm_bearer_access_type_preference_get_string:
 * @val: a MMBearerAccessTypePreference.
 *
 * Gets the nickname string for the #MMBearerAccessTypePreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_bearer_access_type_preference_get_string (MMBearerAccessTypePreference val);
GType mm_bearer_profile_source_get_type (void) G_GNUC_CONST;
#define MM_TYPE_BEARER_PROFILE_SOURCE (mm_bearer_profile_source_get_type ())

/**
 * mm_bearer_profile_source_get_string:
 * @val: a MMBearerProfileSource.
 *
 * Gets the nickname string for the #MMBearerProfileSource specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_bearer_profile_source_get_string (MMBearerProfileSource val);
GType mm_serving_cell_type_get_type (void) G_GNUC_CONST;
#define MM_TYPE_SERVING_CELL_TYPE (mm_serving_cell_type_get_type ())

/**
 * mm_serving_cell_type_get_string:
 * @val: a MMServingCellType.
 *
 * Gets the nickname string for the #MMServingCellType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_serving_cell_type_get_string (MMServingCellType val);
GType mm_network_error_get_type (void) G_GNUC_CONST;
#define MM_TYPE_NETWORK_ERROR (mm_network_error_get_type ())

/**
 * mm_network_error_get_string:
 * @val: a MMNetworkError.
 *
 * Gets the nickname string for the #MMNetworkError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 */
const gchar *mm_network_error_get_string (MMNetworkError val);
G_END_DECLS

#endif /* __MM_ENUMS_TYPES_H__ */

/* Generated data ends here */

